# WG Utilities
[![Code Style](https://img.shields.io/badge/code%20style-black-black)](https://github.com/worgarside/wg-utilities)
[![codecov](https://codecov.io/gh/worgarside/wg-utilities/branch/develop/graph/badge.svg?token=5IJW9KBSV6)](https://codecov.io/gh/worgarside/wg-utilities)
[![GitHub](https://img.shields.io/github/v/tag/worgarside/wg-utilities?logo=github&sort=semver)](https://github.com/worgarside/wg-utilities)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/worgarside/wg-utilities/develop.svg)](https://results.pre-commit.ci/latest/github/worgarside/wg-utilities/develop)
[![PyPI](https://img.shields.io/pypi/v/wg-utilities.svg?logo=python)](https://pypi.python.org/pypi/wg-utilities)

Loads of useful stuff for the things I do :)

### To-Do List
 - [ ] Finish README
 - [x] Add Coverage Badge

### Unit Test Coverage

[![Fancy coverage chart](https://codecov.io/gh/worgarside/wg-utilities/branch/develop/graphs/tree.svg?token=5IJW9KBSV6)](https://codecov.io/gh/worgarside/wg-utilities)
